# Credits

## Maintainers

* [Francesco Fuggitti](https://github.com/francescofuggitti) <[francesco.fuggitti@gmail.com](mailto:francesco.fuggitti@gmail.com)>
* [Tathagata Chakraborti](http://tchakra2.com) <[tathagata.chakraborti1@ibm.com](mailto:tathagata.chakraborti1@ibm.com)>

## Contributors

None yet. [Why not be the first](./contributing.md)? 